@@ -11,7 +11,7 @@ use Text::ParseWords qw/shellwords/;
 use Alien::Util;
 
 # ABSTRACT: Base classes for Alien:: modules
-our $VERSION = '2.52'; # VERSION
+our $VERSION = '2.53'; # VERSION
 
 
 sub import {
@@ -477,7 +477,7 @@ sub alien_helper {
 sub inline_auto_include {
   my ($class) = @_;
   return [] unless $class->config('inline_auto_include');
-  $class->config('inline_auto_include')
+  $class->runtime_prop->{inline_auto_include} || $class->config('inline_auto_include')
 }
 
 sub Inline {
@@ -602,7 +602,7 @@ Alien::Base - Base classes for Alien:: modules
 
 =head1 VERSION
 
-version 2.52
+version 2.53
 
 =head1 SYNOPSIS
 
